/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#include <setjmp.h>
#include <dirent.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <time.h>
#include <unistd.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg;
typedef struct tyTuple__nF9cH4hinXgGEUwO4G2bshw tyTuple__nF9cH4hinXgGEUwO4G2bshw;
typedef struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ;
typedef struct tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA;
typedef struct tySequence__RNhZxf20g9beyq5VBOGxhDg tySequence__RNhZxf20g9beyq5VBOGxhDg;
typedef struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ;
typedef struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ tySequence__lFbCtu5P2Kf7YDYtGjkxAQ;
typedef struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA;
typedef struct tySequence__ijtae5OneaLys0hN9alAicA tySequence__ijtae5OneaLys0hN9alAicA;
typedef struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w;
typedef struct tySequence__SerjNoUujW2dUouVBrJiCw tySequence__SerjNoUujW2dUouVBrJiCw;
typedef struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyObject_Table__r0v8BdcBPKhl73K8p2VMUA;
typedef struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g tySequence__K9agbtcb0qPZuSJFXB9cTe6g;
typedef struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg;
typedef struct tySequence__m88qdML9cQOuqGAQn6XWL1A tySequence__m88qdML9cQOuqGAQn6XWL1A;
typedef struct tyObject_Table__1hIWbTQWYT4BmhdESze57A tyObject_Table__1hIWbTQWYT4BmhdESze57A;
typedef struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ tySequence__naEbXEp9b9aiW1zXJorqf9cXQ;
typedef struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
typedef struct tyObject_Table__imojfg883tkWsWJwyshGqQ tyObject_Table__imojfg883tkWsWJwyshGqQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg tyObject_Table__BCPh85PHtwxox9bv7NLFrlg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA;
typedef struct tySequence__KgiZ29chkJAD01p9aLRB32qw tySequence__KgiZ29chkJAD01p9aLRB32qw;
typedef struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A tyObject_Table__LM44poVdVEn4Mo4N4L8c3A;
typedef struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw tySequence__rkYRZrbHVYL3nhXlQW3K9bw;
typedef struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ tySequence__IRFEb1e9bxgbJLuB5xrdZsQ;
typedef struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ;
typedef struct tySequence__YmPd0eWfcTfrVYrthlXPYA tySequence__YmPd0eWfcTfrVYrthlXPYA;
typedef struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q;
typedef struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg tySequence__Hz5SYwQU29b9aFLt09blvVQPg;
typedef struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg tyObject_Table__R7JnJQEipxxOlJWXQz7jWg;
typedef struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ tySequence__3G9aA9cLXaPxuRxMKm3anacQ;
typedef struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q tySequence__bPFv6ypvvCX2A9a9al8utL2Q;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q tySequence__YdLNCDKYeipzJx3I8Xw82Q;
typedef struct tySequence__Gl8s23LA3EFz4kIlya9ameg tySequence__Gl8s23LA3EFz4kIlya9ameg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw;
typedef struct tySequence__eJWcQvhuN2q0rM6THoByqQ tySequence__eJWcQvhuN2q0rM6THoByqQ;
typedef struct tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw;
typedef struct tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ;
typedef struct tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g;
typedef struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA;
typedef struct Exception Exception;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ;
typedef struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g tySequence__qeAsXh2i1GAL5Nl0g3OP8g;
typedef struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg;
typedef struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg;
typedef struct tySequence__4Murtwnm0Fyc7F9acrytEXw tySequence__4Murtwnm0Fyc7F9acrytEXw;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw;
typedef struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg tySequence__QnmOtn1Iv4LvxOXoMn8Rbg;
typedef struct tySequence__oKtVqsc9bQVCNyrijELM4OQ tySequence__oKtVqsc9bQVCNyrijELM4OQ;
typedef struct tySequence__qy6Iwdy00wN560qud54HTg tySequence__qy6Iwdy00wN560qud54HTg;
typedef struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ tySequence__k67v9bwvvQDmS1ynyGGUbeQ;
typedef struct tySequence__cLsClAAfd0MKkoBQVyvdvw tySequence__cLsClAAfd0MKkoBQVyvdvw;
typedef struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg tySequence__q9bTuOB0JXh1iZ3CSGdRLbg;
typedef struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw;
typedef struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ;
typedef struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ;
typedef struct tySequence__C3r8jsj9chA4sIlYfDN5aDw tySequence__C3r8jsj9chA4sIlYfDN5aDw;
typedef struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ;
typedef struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg tyTuple__UluY8x0Nj6cp9b0o88wJ0lg;
typedef struct tySequence__dlD6tEGzYLLpKVq3XwuFlA tySequence__dlD6tEGzYLLpKVq3XwuFlA;
typedef struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ;
typedef struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg;
typedef struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ;
typedef struct tyTuple__rZZA0skon1OsHdiEvT8RZQ tyTuple__rZZA0skon1OsHdiEvT8RZQ;
typedef struct tySequence__6OFCSvqRaxyEgUqWtnZSlw tySequence__6OFCSvqRaxyEgUqWtnZSlw;
typedef struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q;
typedef struct tySequence__UnGSk9aaLosDroi2QDrlOfQ tySequence__UnGSk9aaLosDroi2QDrlOfQ;
typedef struct tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA;
typedef struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA tyTuple__q13Zt16VkCqu6Zg5jWqwHA;
typedef struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA tyTuple__aWN9bNzF9bubXNJV9ciomgpfA;
typedef struct tySequence__m4PVWjcAAjfxlwJxLkKn8A tySequence__m4PVWjcAAjfxlwJxLkKn8A;
typedef struct tyTuple__RWXAsQlFoGYyEQZp1G65sg tyTuple__RWXAsQlFoGYyEQZp1G65sg;
typedef struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg;
typedef struct tyTuple__RmGJuqOgEaHckHndh0LEsw tyTuple__RmGJuqOgEaHckHndh0LEsw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__J4cxakKjhKxTIJR9bojMmXw tyTuple__J4cxakKjhKxTIJR9bojMmXw;
typedef struct tySequence__i89c5kdtWKzK3OEiI81pkkw tySequence__i89c5kdtWKzK3OEiI81pkkw;
typedef struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A;
typedef struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ;
typedef struct tySequence__GR8qmV1kNRcoQ2g76VFy3A tySequence__GR8qmV1kNRcoQ2g76VFy3A;
typedef struct tyTuple__a7QginWFapakKbWJBJ2vfA tyTuple__a7QginWFapakKbWJBJ2vfA;
typedef struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__kbX6x85REySUrk9auORL0vw tyTuple__kbX6x85REySUrk9auORL0vw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g;
typedef struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q;
typedef struct tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A;
typedef struct tyTuple__5pg9aIYdyrJM6GlDgyTDumg tyTuple__5pg9aIYdyrJM6GlDgyTDumg;
typedef struct tyTuple__0y4YQo9b9byJ83c0H89bBtdRw tyTuple__0y4YQo9b9byJ83c0H89bBtdRw;
typedef struct tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA;
typedef struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__PsEhl3dzznmmJiLAuIXZOg tyTuple__PsEhl3dzznmmJiLAuIXZOg;
typedef struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w;
typedef struct tyTuple__Db8CrQifKGIsKc3w71w7Lw tyTuple__Db8CrQifKGIsKc3w71w7Lw;
typedef struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg;
typedef struct tySequence__lo3S1lKyiPLhGGB9cBawd6A tySequence__lo3S1lKyiPLhGGB9cBawd6A;
typedef struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ;
typedef struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw tyTuple__FEYH9alRJhHD0uTKF2vnIqw;
typedef struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA;
typedef struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA;
typedef struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw;
typedef struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg tyTuple__VUJ5Hjm4tKAResBsRHJvYg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, tyProc__kqPx9c4py2HW6KcFMhNvxtg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__9c6qRjwy7Es8UkDTIUwAfFA) (tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__mv4BsRs5VEnhcxzV6pQU5w) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
struct tyTuple__nF9cH4hinXgGEUwO4G2bshw {
tyProc__kqPx9c4py2HW6KcFMhNvxtg Field0;
tyProc__9c6qRjwy7Es8UkDTIUwAfFA Field1;
tyProc__mv4BsRs5VEnhcxzV6pQU5w Field2;
NIM_BOOL Field3;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
struct tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA {
  RootObj Sup;
NI colonstate_;
NimStringDesc* errorMsg1;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph2;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf3;
NimStringDesc* vthisDir4;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module5;
};
struct tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA {
tySequence__ijtae5OneaLys0hN9alAicA* data;
NI counter;
};
struct tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w {
tySequence__SerjNoUujW2dUouVBrJiCw* data;
NI counter;
};
struct tyObject_Table__r0v8BdcBPKhl73K8p2VMUA {
tySequence__K9agbtcb0qPZuSJFXB9cTe6g* data;
NI counter;
};
typedef tyObject_Table__r0v8BdcBPKhl73K8p2VMUA tyArray__46hjIasL27aUz9c7kgtWooQ[5];
struct tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg {
tySequence__m88qdML9cQOuqGAQn6XWL1A* data;
NI counter;
};
struct tyObject_Table__1hIWbTQWYT4BmhdESze57A {
tySequence__naEbXEp9b9aiW1zXJorqf9cXQ* data;
NI counter;
};
struct tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
};
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__imojfg883tkWsWJwyshGqQ {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__BCPh85PHtwxox9bv7NLFrlg {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA {
tySequence__KgiZ29chkJAD01p9aLRB32qw* data;
NI counter;
};
struct tyObject_Table__LM44poVdVEn4Mo4N4L8c3A {
tySequence__rkYRZrbHVYL3nhXlQW3K9bw* data;
NI counter;
};
typedef tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg[65];
struct tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ {
tySequence__YmPd0eWfcTfrVYrthlXPYA* data;
NI counter;
};
struct tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, tyProc__I6rzVhdiYtUh7jwWJQoeyw) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, tyProc__EQOAUyRkp9c3eeiGlHvCThA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m, NI32 fileIdx);
struct tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q {
tySequence__Hz5SYwQU29b9aFLt09blvVQPg* data;
NI counter;
};
struct tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__R7JnJQEipxxOlJWXQz7jWg {
tySequence__3G9aA9cLXaPxuRxMKm3anacQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__1CO5eEh25fBKUWGagpikwg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
typedef N_NIMCALL_PTR(void, tyProc__VcUg5jOhttLagdxUmVN8Tg) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__XOkru1xuh2bHzmkw1UYzLA) (tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* formal, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* actual);
struct tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opNot;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opContains;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLe;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLt;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAnd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opOr;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opIsNil;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opEq;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opAdd;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opSub;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opMul;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opDiv;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg {
tySequence__RNhZxf20g9beyq5VBOGxhDg* ifaces;
tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ* packed_0;
tySequence__lFbCtu5P2Kf7YDYtGjkxAQ* encoders;
tyObject_Table__nODIJ5l6JnEl9a6LYuqISLA typeInstCache;
tyObject_Table__s3itmS9cUUFQ19alF7UA0T1w procInstCache;
tyArray__46hjIasL27aUz9c7kgtWooQ attachedOps;
tyObject_Table__KsPP7K7LW9aa3YAq1XN9cDZg methodsPerType;
tyObject_Table__1hIWbTQWYT4BmhdESze57A enumToStringProcs;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw emittedTypeInfo;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA startupPackedConfig;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw deps;
tyObject_Table__imojfg883tkWsWJwyshGqQ importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__BCPh85PHtwxox9bv7NLFrlg inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* usageSym;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* owners;
tyObject_Table__mLYbj79bHyPPDPv4GGJx9bqA suggestSymbols;
tyObject_Table__LM44poVdVEn4Mo4N4L8c3A suggestErrors;
tySequence__IRFEb1e9bxgbJLuB5xrdZsQ* methods;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* systemModule;
tyArray__9atk2qEPO7ASGmt9cDlOE9b9cg sysTypes;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw compilerprocs;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw exposed;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw packageTypes;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
tyObject_Table__sEMwnZ9aATDhH19cNIt9bn9cyQ canonTypes;
tyObject_Table__WtPprFMQ6tkKi9bQSH3IVpw symBodyHashes;
tyProc__I6rzVhdiYtUh7jwWJQoeyw importModuleCallback;
tyProc__EQOAUyRkp9c3eeiGlHvCThA includeFileCallback;
tyObject_Table__9cOd7jTOg5Zc4i0IfnGho1Q cacheSeqs;
tyObject_Table__YnoEqrDMrd9cI9bBg8gj5H3g cacheCounters;
tyObject_Table__R7JnJQEipxxOlJWXQz7jWg cacheTables;
tySequence__bPFv6ypvvCX2A9a9al8utL2Q* passes;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinition;
tyProc__1CO5eEh25fBKUWGagpikwg onDefinitionResolveForward;
tyProc__1CO5eEh25fBKUWGagpikwg onUsage;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* globalDestructors;
tyProc__VcUg5jOhttLagdxUmVN8Tg strongSemCheck;
tyProc__XOkru1xuh2bHzmkw1UYzLA compatibleProps;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
tyObject_Operators__dR4s9bCO53rZjV9a30JJfUOg operators;
};
struct tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw {
  RootObj Sup;
tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen;
};
typedef NU8 tyEnum_TEvalMode__iWSxkwmhTDY7fh9aYmp69akQ;
typedef NU8 tySet_tyEnum_TSandboxFlag__6jKj8dTCDIUGegA1P2RahA;
struct tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw {
NF tEnter;
tyObject_TStackFrame__0GloFoQJxIWYG3W9cguBcAQ* tos;
};
struct tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg {
tySequence__E8pi9b5QNahsURYzXMjh3qw* data;
NI counter;
};
struct tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ {
  tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw Sup;
tySequence__YdLNCDKYeipzJx3I8Xw82Q* code;
tySequence__Gl8s23LA3EFz4kIlya9ameg* debug;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* globals;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constants;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currentExceptionA;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currentExceptionB;
NI exceptionInstr;
tyObject_PProccolonObjectType___1XP6mUlNhJdzLnDeBOqcVw* prc;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* callsite;
tyEnum_TEvalMode__iWSxkwmhTDY7fh9aYmp69akQ mode;
tySet_tyEnum_TSandboxFlag__6jKj8dTCDIUGegA1P2RahA features;
NIM_BOOL traceActive;
NI loopIterations;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw comesFromHeuristic;
tySequence__eJWcQvhuN2q0rM6THoByqQ* callbacks;
NimStringDesc* errorFlag;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
NI oldErrorCount;
tyObject_Profiler__vPk6nUD8QeNW2bHH4WZfpw profiler;
NI* templInstCounter;
tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g* vmstateDiff;
tyObject_Table__7ACYz5IhOEwzTBvwo6BO9bg procToCodePos;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
void* ClE_0;
} tyProc__vkuGXw0bPP9b9cpazTHQY9bqg;
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU8 tySet_tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw;
typedef NU8 tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw;
typedef NIM_CHAR tyArray__dTlC27m9c9aWd5dvuePYanug[256];
typedef NU8 tySet_tyEnum_CopyFlag__FAQfI6ph9a9bh5nGNKhOYumg;
struct tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA {
NI64 seconds;
NI nanosecond;
};
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef N_CLOSURE_PTR(void, TM__qdmBYobaV9btoxwHZNavLQA_40) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__qdmBYobaV9btoxwHZNavLQA_42) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__qdmBYobaV9btoxwHZNavLQA_44) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__qdmBYobaV9btoxwHZNavLQA_46) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__qdmBYobaV9btoxwHZNavLQA_48) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__qdmBYobaV9btoxwHZNavLQA_50) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__qdmBYobaV9btoxwHZNavLQA_60) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__qdmBYobaV9btoxwHZNavLQA_62) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__qdmBYobaV9btoxwHZNavLQA_64) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__qdmBYobaV9btoxwHZNavLQA_66) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef NU8 tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w;
typedef NU16 tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw;
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef N_CLOSURE_PTR(void, TM__qdmBYobaV9btoxwHZNavLQA_77) (tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* args, void* ClE_0);
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* converters;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* patterns;
tySequence__qeAsXh2i1GAL5Nl0g3OP8g* pureEnums;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interf;
tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw interfHidden;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* uniqueName;
};
typedef NU8 tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg;
struct tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg {
tySequence__4Murtwnm0Fyc7F9acrytEXw* nodes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ;
struct tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ {
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw {
tySequence__IHUFRsFxZNv7YydiUO2esQ* vals;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* keys;
};
struct tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag {
NimStringDesc* definedSymbols;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA moduleFlags;
tySequence__PXIzfWocnrafGz5p3CP5LA* includes;
tySequence__9bAGqSvkAaFL9bWjsEPslrFA* imports;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg toReplay;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg topLevel;
tyObject_PackedTree__om9aqqVmbmBPgd8MeBkGtqg bodies;
tySequence__b89aLriiJnVTD186H6zNIgg* exports;
tySequence__b89aLriiJnVTD186H6zNIgg* hidden;
tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw* reexports;
tySequence__b89aLriiJnVTD186H6zNIgg* compilerProcs;
tySequence__48JTohSgTy339bRxHzUD8KA* converters;
tySequence__48JTohSgTy339bRxHzUD8KA* methods;
tySequence__48JTohSgTy339bRxHzUD8KA* trmacros;
tySequence__48JTohSgTy339bRxHzUD8KA* pureEnums;
tySequence__QnmOtn1Iv4LvxOXoMn8Rbg* macroUsages;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* typeInstCache;
tySequence__qy6Iwdy00wN560qud54HTg* procInstCache;
tySequence__k67v9bwvvQDmS1ynyGGUbeQ* attachedOps;
tySequence__cLsClAAfd0MKkoBQVyvdvw* methodsPerType;
tySequence__oKtVqsc9bQVCNyrijELM4OQ* enumToStringProcs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* emittedTypeInfo;
tySet_tyEnum_ModuleBackendFlag__1OX8mHZmOJcGSH2EQV6eCQ backendFlags;
tySequence__q9bTuOB0JXh1iZ3CSGdRLbg* syms;
tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw* types;
tyObject_BiTable__f1TRECC4Lgx6Suak6pB8oQ strings;
tyObject_BiTable__YFXXoy9ajAIwHK4kQgVvjcw numbers;
tyObject_PackedConfig__aqQhF9bElTH51s7bVamv3vA cfg;
};
struct tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ {
tySequence__C3r8jsj9chA4sIlYfDN5aDw* data;
NI counter;
};
struct tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg {
tyEnum_ModuleStatus__K6X1Kd9cJ9a0hyG1Twv69bMNg status;
NIM_BOOL symsInit;
NIM_BOOL typesInit;
NIM_BOOL loadedButAliveSetChanged;
tyObject_PackedModule__Lx6uQ9baEALysaHmfFGXw9ag fromDisk;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* syms;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* types;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ iface;
tyObject_Table__jSCM9c8LtAedYb1zTNR73sQ ifaceHidden;
};
struct tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ {
tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data;
NI counter;
};
struct tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ {
NI32 thisModule;
NI32 lastFile;
NU32 lastLit;
tyObject_Table__7OytuYts9c9a3BX9aQNPGI0gQ filenames;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* pendingTypes;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* pendingSyms;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw typeMarker;
tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw symMarker;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
struct tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ {
NU32 module;
NI32 item;
};
struct tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg {
NI module;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ packed_0;
};
struct tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
};
struct tyTuple__UluY8x0Nj6cp9b0o88wJ0lg {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__dlD6tEGzYLLpKVq3XwuFlA* Field2;
};
struct tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q {
NI module;
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg sym;
tySequence__UnGSk9aaLosDroi2QDrlOfQ* concreteTypes;
tyObject_TInstantiation__ScJwrSJM8Lp9ahM9b3AS1apA* inst;
};
struct tyTuple__rZZA0skon1OsHdiEvT8RZQ {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__6OFCSvqRaxyEgUqWtnZSlw* Field2;
};
struct tyTuple__q13Zt16VkCqu6Zg5jWqwHA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field2;
};
struct tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg {
tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg id;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
};
struct tyTuple__RWXAsQlFoGYyEQZp1G65sg {
NI Field0;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field1;
};
struct tyTuple__aWN9bNzF9bubXNJV9ciomgpfA {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tySequence__m4PVWjcAAjfxlwJxLkKn8A* Field2;
};
struct tyTuple__RmGJuqOgEaHckHndh0LEsw {
NI Field0;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg Field1;
tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg Field2;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
};
struct tyTuple__J4cxakKjhKxTIJR9bojMmXw {
NI Field0;
NI32 Field1;
tySequence__i89c5kdtWKzK3OEiI81pkkw* Field2;
};
struct tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ {
NI Field0;
NI32 Field1;
tySequence__GR8qmV1kNRcoQ2g76VFy3A* Field2;
};
struct tyTuple__a7QginWFapakKbWJBJ2vfA {
tySequence__ed0C0uAUZPhvw3RAc5hfYg* Field0;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__kbX6x85REySUrk9auORL0vw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q {
tyObject_NodecolonObjectType___NOM0ZpqV9bLtofkCilAnZ8A* root;
NI entries;
};
struct tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__R2EgvhuH9cLMYvSPesdcu5Q Field2;
};
struct tyTuple__5pg9aIYdyrJM6GlDgyTDumg {
NimStringDesc* Field0;
tyProc__vkuGXw0bPP9b9cpazTHQY9bqg Field1;
};
struct tyTuple__0y4YQo9b9byJ83c0H89bBtdRw {
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* Field0;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* Field1;
};
struct tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA {
NI ra;
NI rb;
NI rc;
tyObject_TFullReg__5wJdjCgIXFtQUOFYtApLgA* slots;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currentException;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw currentLineInfo;
};
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
NU32 Field0;
NimStringDesc* Field1;
};
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
struct tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA {
NU16 line;
NI16 col;
NU32 file;
};
struct tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA {
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
NI32 operand;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeId_0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
NU32 Field0;
NI32 Field1;
};
struct tyTuple__PsEhl3dzznmmJiLAuIXZOg {
NU32 Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA Field1;
};
struct tyTuple__Db8CrQifKGIsKc3w71w7Lw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
};
struct tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ key;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* concreteTypes;
};
typedef NU8 tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ;
struct tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ {
tyEnum_TTypeAttachedOp__0IDqFfYT9a3F5i6tmCmdORQ Field0;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
struct tyTuple__FEYH9alRJhHD0uTKF2vnIqw {
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field0;
NI Field1;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ Field2;
};
typedef NU8 tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ;
struct tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA {
tyEnum_TLibKind__tW9cjoYNrpn2JX4q6fqRnxQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
NU32 name;
NI32 path;
};
struct tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA {
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
NU32 name;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typ;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_PackedLineInfo__wqhF27DCtLcrB2XHUZKKiA info;
NI32 ast;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ guard;
NI bitsize;
NI alignment;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
NU32 externalName;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw locFlags;
tyObject_PackedLib__djDv9aFBRsdjnMVLdFGA0nA annex;
NI32 constraint;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw {
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* types;
NI32 n;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ sym;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ owner;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ typeInst;
NI32 nonUniqueId;
};
struct tyTuple__VUJ5Hjm4tKAResBsRHJvYg {
NI Field0;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* Field1;
tySequence__lo3S1lKyiPLhGGB9cBawd6A* Field2;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
NI Field0;
NI32 Field1;
NU32 Field2;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__RNhZxf20g9beyq5VBOGxhDg {
  TGenericSeq Sup;
  tyObject_Iface__4y9aWdJBxraQYTl5Pa1NMuQ data[SEQ_DECL_SIZE];
};
struct tySequence__JbK5aK9aVhc9cJZzQYg1wQlQ {
  TGenericSeq Sup;
  tyObject_LoadedModule__fihS6xbKhtLC0fhM28Cpeg data[SEQ_DECL_SIZE];
};
struct tySequence__lFbCtu5P2Kf7YDYtGjkxAQ {
  TGenericSeq Sup;
  tyObject_PackedEncoder__ftUl9bxYRlbT5ToKkxHdbfQ data[SEQ_DECL_SIZE];
};
struct tySequence__dlD6tEGzYLLpKVq3XwuFlA {
  TGenericSeq Sup;
  tyObject_LazyType__wgv9a1JCOBXm9azerxcvz5gQ data[SEQ_DECL_SIZE];
};
struct tySequence__ijtae5OneaLys0hN9alAicA {
  TGenericSeq Sup;
  tyTuple__UluY8x0Nj6cp9b0o88wJ0lg data[SEQ_DECL_SIZE];
};
struct tySequence__6OFCSvqRaxyEgUqWtnZSlw {
  TGenericSeq Sup;
  tyObject_LazyInstantiation__0l1i6PfjQKnMEvpGMAoN8Q data[SEQ_DECL_SIZE];
};
struct tySequence__SerjNoUujW2dUouVBrJiCw {
  TGenericSeq Sup;
  tyTuple__rZZA0skon1OsHdiEvT8RZQ data[SEQ_DECL_SIZE];
};
struct tySequence__K9agbtcb0qPZuSJFXB9cTe6g {
  TGenericSeq Sup;
  tyTuple__q13Zt16VkCqu6Zg5jWqwHA data[SEQ_DECL_SIZE];
};
struct tySequence__m4PVWjcAAjfxlwJxLkKn8A {
  TGenericSeq Sup;
  tyTuple__RWXAsQlFoGYyEQZp1G65sg data[SEQ_DECL_SIZE];
};
struct tySequence__m88qdML9cQOuqGAQn6XWL1A {
  TGenericSeq Sup;
  tyTuple__aWN9bNzF9bubXNJV9ciomgpfA data[SEQ_DECL_SIZE];
};
struct tySequence__naEbXEp9b9aiW1zXJorqf9cXQ {
  TGenericSeq Sup;
  tyTuple__RmGJuqOgEaHckHndh0LEsw data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__i89c5kdtWKzK3OEiI81pkkw {
  TGenericSeq Sup;
  tyObject_SymInfoPair__SjZT5Rln3r9befMWWSryQ0A data[SEQ_DECL_SIZE];
};
struct tySequence__KgiZ29chkJAD01p9aLRB32qw {
  TGenericSeq Sup;
  tyTuple__J4cxakKjhKxTIJR9bojMmXw data[SEQ_DECL_SIZE];
};
struct tySequence__GR8qmV1kNRcoQ2g76VFy3A {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* data[SEQ_DECL_SIZE];
};
struct tySequence__rkYRZrbHVYL3nhXlQW3K9bw {
  TGenericSeq Sup;
  tyTuple__VwWg1orPZ9b5Rg9aZAI6SIaQ data[SEQ_DECL_SIZE];
};
struct tySequence__IRFEb1e9bxgbJLuB5xrdZsQ {
  TGenericSeq Sup;
  tyTuple__a7QginWFapakKbWJBJ2vfA data[SEQ_DECL_SIZE];
};
struct tySequence__YmPd0eWfcTfrVYrthlXPYA {
  TGenericSeq Sup;
  tyTuple__mPT6B9cVWqwVnWb1Fxx9bgyA data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__Hz5SYwQU29b9aFLt09blvVQPg {
  TGenericSeq Sup;
  tyTuple__kbX6x85REySUrk9auORL0vw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3G9aA9cLXaPxuRxMKm3anacQ {
  TGenericSeq Sup;
  tyTuple__Ah6ua9a8WyUOs9aO9afW59cy0g data[SEQ_DECL_SIZE];
};
struct tySequence__bPFv6ypvvCX2A9a9al8utL2Q {
  TGenericSeq Sup;
  tyTuple__nF9cH4hinXgGEUwO4G2bshw data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q {
  TGenericSeq Sup;
  NU64 data[SEQ_DECL_SIZE];
};
struct tySequence__Gl8s23LA3EFz4kIlya9ameg {
  TGenericSeq Sup;
  tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__eJWcQvhuN2q0rM6THoByqQ {
  TGenericSeq Sup;
  tyTuple__5pg9aIYdyrJM6GlDgyTDumg data[SEQ_DECL_SIZE];
};
struct tySequence__ztPIC2M9bqhs0KjYuE9c9cN8g {
  TGenericSeq Sup;
  tyTuple__0y4YQo9b9byJ83c0H89bBtdRw data[SEQ_DECL_SIZE];
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  TGenericSeq Sup;
  tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
struct tySequence__qeAsXh2i1GAL5Nl0g3OP8g {
  TGenericSeq Sup;
  tyObject_LazySym__Xts9a2Mw4b4jtq73p6MrfJg data[SEQ_DECL_SIZE];
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  TGenericSeq Sup;
  tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  TGenericSeq Sup;
  NU32 data[SEQ_DECL_SIZE];
};
struct tySequence__4Murtwnm0Fyc7F9acrytEXw {
  TGenericSeq Sup;
  tyObject_PackedNode__9aA1ZskrZ0b0RCXxY4Hw8YA data[SEQ_DECL_SIZE];
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  TGenericSeq Sup;
  tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tySequence__wE9cZkGC9cv7Iz9ckZOIyaW9aw {
  TGenericSeq Sup;
  tyTuple__PsEhl3dzznmmJiLAuIXZOg data[SEQ_DECL_SIZE];
};
struct tySequence__QnmOtn1Iv4LvxOXoMn8Rbg {
  TGenericSeq Sup;
  tyTuple__Dg3ILQdzHFjrYRx6Xwbq3w data[SEQ_DECL_SIZE];
};
struct tySequence__oKtVqsc9bQVCNyrijELM4OQ {
  TGenericSeq Sup;
  tyTuple__Db8CrQifKGIsKc3w71w7Lw data[SEQ_DECL_SIZE];
};
struct tySequence__qy6Iwdy00wN560qud54HTg {
  TGenericSeq Sup;
  tyObject_PackedInstantiation__wt9ao6lqcInu9aOmUoxgkWcg data[SEQ_DECL_SIZE];
};
struct tySequence__k67v9bwvvQDmS1ynyGGUbeQ {
  TGenericSeq Sup;
  tyTuple__Q9cwWJO3ddVfos2xI7N9cHHQ data[SEQ_DECL_SIZE];
};
struct tySequence__cLsClAAfd0MKkoBQVyvdvw {
  TGenericSeq Sup;
  tyTuple__FEYH9alRJhHD0uTKF2vnIqw data[SEQ_DECL_SIZE];
};
struct tySequence__q9bTuOB0JXh1iZ3CSGdRLbg {
  TGenericSeq Sup;
  tyObject_PackedSym__fAjcBcJ2JPtzDDxyIN8WmA data[SEQ_DECL_SIZE];
};
struct tySequence__DPZr9aMyRppVlNZ9ajSyOZ9bw {
  TGenericSeq Sup;
  tyObject_PackedType__MvipqCfEd9b9bJbbBPwsUOiw data[SEQ_DECL_SIZE];
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  TGenericSeq Sup;
  NI64 data[SEQ_DECL_SIZE];
};
struct tySequence__lo3S1lKyiPLhGGB9cBawd6A {
  TGenericSeq Sup;
  tyObject_PackedItemId__QkYBSICiQaMI6SmH4FJVoQ data[SEQ_DECL_SIZE];
};
struct tySequence__C3r8jsj9chA4sIlYfDN5aDw {
  TGenericSeq Sup;
  tyTuple__VUJ5Hjm4tKAResBsRHJvYg data[SEQ_DECL_SIZE];
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  TGenericSeq Sup;
  tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tySequence__UnGSk9aaLosDroi2QDrlOfQ {
  TGenericSeq Sup;
  tyObject_FullId__L64puUgQnoQ6OMvT9c6V9cPg data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg*, newModuleGraph__modulegraphs_9478)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(void, connectCallbacks__modules_1183)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph);
N_LIB_PRIVATE N_NIMCALL(void, initDefines__condsyms_18)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__condsyms_4)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols, NimStringDesc* symbol, NimStringDesc* value);
N_LIB_PRIVATE N_NIMCALL(void, registerPass__passes_63)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyTuple__nF9cH4hinXgGEUwO4G2bshw* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, myOpen__sem_22328)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myProcess__sem_22542)(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* context, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myClose__sem_22570)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* context, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw*, myOpen__vm_14031)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myProcess__vm_14036)(tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, myClose__vm_14041)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TPassContext__dmp6pRpfXxJk6gIZHkm7dw* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5267)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__condsyms_8)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, makeModule__modules_1225)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ*, setupVM__scriptconfig_39)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NimStringDesc* scriptName, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__X7o3ECzpPdUpRzG3oZpgiQ)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ*, newCtx__vmdef_367)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen);
N_LIB_PRIVATE N_NIMCALL(void, registerAdditionalOps__vm_13319)(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* c);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringDesc* path, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NI, registerCallback__vmdef_518)(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* c, NimStringDesc* name, tyProc__vkuGXw0bPP9b9cpazTHQY9bqg callback);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_59)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(void, listDirs__scriptconfig_20)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, tySet_tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw filter);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getString__vm_368)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, NI i);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s);
N_LIB_PRIVATE N_NOINLINE(void, raiseOSError__pureZos_405)(NI32 errorCode, NimStringDesc* additionalInfo);
N_LIB_PRIVATE N_NIMCALL(NI32, osLastError__pureZos_408)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, cstrToNimstr)(NCSTRING str);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosjoinPath)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosdirExists)(NimStringDesc* dir);
N_LIB_PRIVATE N_NIMCALL(tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw, getSymlinkFileKind__pureZos_1244)(NimStringDesc* path);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_258)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, tySequence__sM4lkSb7zS6F7OVMvW9cffQ* v);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(NimStringDesc*, getCurrentExceptionMsg__system_6984)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_61)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_63)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, nosremoveDir)(NimStringDesc* dir, NIM_BOOL checkDir);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, getBool__vm_314)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, NI i);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_69)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, nosremoveFile)(NimStringDesc* file);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_75)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, noscreateDir)(NimStringDesc* dir);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_77)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_249)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, NimStringDesc* v);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_79)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
static N_INLINE(void, setCurrentDir__pureZos_732)(NimStringDesc* newDir);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_81)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetCurrentDir)(void);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_83)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, nosmoveFile)(NimStringDesc* source, NimStringDesc* dest);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_89)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, moveDir__pureZos_1461)(NimStringDesc* source, NimStringDesc* dest);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_95)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, noscopyFile)(NimStringDesc* source, NimStringDesc* dest, tySet_tyEnum_CopyFlag__FAQfI6ph9a9bh5nGNKhOYumg options);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_101)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, noscopyDir)(NimStringDesc* source, NimStringDesc* dest);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_107)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_236)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, NI64 v);
N_LIB_PRIVATE N_NIMCALL(NI64, toUnix__pureZtimes_917)(tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA, nosgetLastModificationTime)(NimStringDesc* file);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_109)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findExe__pureZos_654)(NimStringDesc* exe, NIM_BOOL followSymlinks, NimStringDesc** extensions, NI extensionsLen_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_111)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NI, nospexecCmd)(NimStringDesc* command);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_117)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getEnv__pureZos_418)(NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_119)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_242)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, NIM_BOOL v);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, existsEnv__pureZos_423)(NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_121)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a);
N_LIB_PRIVATE N_NIMCALL(void, putEnv__pureZos_426)(NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_123)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a);
N_LIB_PRIVATE N_NIMCALL(void, delEnv__pureZos_465)(NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_125)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_127)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringDesc* filename);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_129)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_131)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_133)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_135)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_137)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setConfigVar__options_4059)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_139)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getConfigVar__options_4054)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_141)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, existsConfigVar__options_4050)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* key);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_143)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimcacheDir__options_4185)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_145)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, paramStr__pureZos_1546)(NI i);
N_LIB_PRIVATE N_NIMCALL(NI64, getInt__vm_279)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, NI i);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_147)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a);
N_LIB_PRIVATE N_NIMCALL(NI, paramCount__pureZos_1552)(void);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_149)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_151)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreCase)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_153)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setCommandEarly__commands_832)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* command);
N_LIB_PRIVATE N_NIMCALL(void, setFromProjectName__options_4123)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* projectName);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_160)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_162)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__commands_880)(NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_164)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, processSpecificNote__commands_274)(NimStringDesc* arg, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw state, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* orig, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_166)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_168)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosaddFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_1631)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, pathSubs__options_4207)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* p, NimStringDesc* config);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_172)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetAppFilename)(void);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_174)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, cppDefine__options_2530)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* c, NimStringDesc* define);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_176)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, readLine__systemZio_273)(FILE* f);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_182)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, readAll__systemZio_352)(FILE* file);
N_LIB_PRIVATE N_NIMCALL(void, compileSystemModule__modules_1203)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processModule__passes_213)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* stream);
N_LIB_PRIVATE N_NIMCALL(void, resetSystemArtifacts__modules_17)(tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* g);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_2, "nimscript", 9);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_3, "true", 4);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_4, "nimconfig", 9);
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_5, "nimv2", 5);
extern TNimType NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTIobject__heNwa9aLhgGVTGhbmP9aqemA_;
extern TNimType NTIint__xHTZrq9aYs6boc9bCba0JbpQ_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
extern TNimType NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_;
extern TNimType NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_;
extern TNimType NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_;
N_LIB_PRIVATE TNimType NTIrefobject__X7o3ECzpPdUpRzG3oZpgiQ_;
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_7, "stdlib.system.listFilesImpl", 27);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_10, ".", 1);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_11, "..", 2);
extern TNimType NTIoserror__THeHlGxHorUQ17FON5jY0g_;
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_12, "stdlib.system.listDirsImpl", 26);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_14, "stdlib.system.removeDir", 23);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_16, "stdlib.system.removeFile", 24);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_18, "stdlib.system.createDir", 23);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_20, "stdlib.system.getError", 22);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_21, "stdlib.system.setCurrentDir", 27);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_23, "stdlib.system.getCurrentDir", 27);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_25, "stdlib.system.moveFile", 22);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_27, "stdlib.system.moveDir", 21);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_29, "stdlib.system.copyFile", 22);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_31, "stdlib.system.copyDir", 21);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_33, "stdlib.system.getLastModificationTime", 37);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_35, "stdlib.system.findExe", 21);
extern NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA ExeExts__pureZos_653;
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_37, "stdlib.system.rawExec", 21);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_39, "stdlib.system.getEnv", 20);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_41, "stdlib.system.existsEnv", 23);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_43, "stdlib.system.putEnv", 20);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_45, "stdlib.system.delEnv", 20);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_47, "stdlib.system.dirExists", 23);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_49, "stdlib.system.fileExists", 24);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_51, "stdlib.system.projectName", 25);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_52, "stdlib.system.projectDir", 24);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_53, "stdlib.system.projectPath", 25);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_54, "stdlib.system.thisDir", 21);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_55, "stdlib.system.put", 17);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_56, "stdlib.system.get", 17);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_57, "stdlib.system.exists", 20);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_58, "stdlib.system.nimcacheDir", 25);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_59, "stdlib.system.paramStr", 22);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_61, "stdlib.system.paramCount", 24);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_63, "stdlib.system.cmpIgnoreStyle", 28);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_65, "stdlib.system.cmpIgnoreCase", 27);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_67, "stdlib.system.setCommand", 24);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_68, "stdlib.system.getCommand", 24);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_69, "stdlib.system.switch", 20);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_70, "stdlib.system.hintImpl", 22);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_71, "stdlib.system.warningImpl", 25);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_72, "stdlib.system.patchFile", 23);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_73, "_", 1);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_74, "nim", 3);
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__qdmBYobaV9btoxwHZNavLQA_75 = {
0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_76, "stdlib.system.selfExe", 21);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_78, "stdlib.system.cppDefine", 23);
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_79, "stdlib.system.stdinReadLine", 27);
extern TNimType NTIeoferror__kIdEdoaj8I8RXN2AU5W3mg_;
STRING_LITERAL(TM__qdmBYobaV9btoxwHZNavLQA_81, "stdlib.system.stdinReadAll", 26);
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5220;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5267((&gch__system_5220.zct), c);
}
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5316(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5273(src);
		incRef__system_5311(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5273((*dest));
		decRef__system_5318(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5273(p);
	decRef__system_5318(T1_);
}
static N_NIMCALL(void, Marker_tyRef__X7o3ECzpPdUpRzG3oZpgiQ)(void* p, NI op) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* a;
	a = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*)p;
	nimGCvisit((void*)(*a).errorMsg1, op);
	nimGCvisit((void*)(*a).graph2, op);
	nimGCvisit((void*)(*a).conf3, op);
	nimGCvisit((void*)(*a).vthisDir4, op);
	nimGCvisit((void*)(*a).module5, op);
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2565;
	excHandler__system_2565 = s;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s) {
	NCSTRING result;
	result = (NCSTRING)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((NimStringDesc*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).Sup.len == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = "";
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((NCSTRING) ((*s).data));
	}
	LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = nosjoinPath(head, tail);
	return result;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2565 = (*excHandler__system_2565).prev;
}
N_LIB_PRIVATE N_NIMCALL(void, listDirs__scriptconfig_20)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, tySet_tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw filter) {
	NimStringDesc* dir;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* result;
	dir = getString__vm_368(a, ((NI) 0));
	result = NIM_NIL;
	{
		tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw kind;
		NimStringDesc* path;
		DIR* d;
		kind = (tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw)0;
		path = NIM_NIL;
		d = opendir(nimToCStringConv(dir));
		{
			if (!(d == ((DIR*) NIM_NIL))) goto LA4_;
			{
				NI32 T10_;
				if (!NIM_FALSE) goto LA8_;
				T10_ = (NI32)0;
				T10_ = osLastError__pureZos_408();
				raiseOSError__pureZos_405(T10_, dir);
			}
			LA8_: ;
		}
		goto LA2_;
		LA4_: ;
		{
			TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_9;
			pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_9);
			TM__qdmBYobaV9btoxwHZNavLQA_9.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_9.context);
			if (TM__qdmBYobaV9btoxwHZNavLQA_9.status == 0) {
			{
				while (1) {
					{
						struct dirent* x;
						NimStringDesc* y;
						x = readdir(d);
						{
							if (!(x == ((struct dirent*) NIM_NIL))) goto LA17_;
							goto LA12;
						}
						LA17_: ;
						y = cstrToNimstr(((NCSTRING) ((*x).d_name)));
						{
							NIM_BOOL T21_;
							struct stat s;
							NimStringDesc* path_2;
							tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw k;
							T21_ = (NIM_BOOL)0;
							T21_ = !(eqStrings(y, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_10)));
							if (!(T21_)) goto LA22_;
							T21_ = !(eqStrings(y, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_11)));
							LA22_: ;
							if (!T21_) goto LA23_;
							nimZeroMem((void*)(&s), sizeof(struct stat));
							path_2 = slash___pureZos_121(dir, y);
							{
								if (!NIM_TRUE) goto LA27_;
								y = copyString(path_2);
							}
							LA27_: ;
							k = ((tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw) 0);
							switch ((*x).d_type) {
							case ((NI) 4):
							{
								k = ((tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw) 2);
							}
							break;
							case ((NI) 10):
							{
								{
									NIM_BOOL T33_;
									T33_ = (NIM_BOOL)0;
									T33_ = nosdirExists(path_2);
									if (!T33_) goto LA34_;
									k = ((tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw) 3);
								}
								goto LA31_;
								LA34_: ;
								{
									k = ((tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw) 1);
								}
								LA31_: ;
							}
							break;
							case ((NI) 0):
							{
								{
									int T40_;
									T40_ = (int)0;
									T40_ = lstat(nimToCStringConv(path_2), (&s));
									if (!(T40_ < ((NI32) 0))) goto LA41_;
									goto LA14;
								}
								goto LA38_;
								LA41_: ;
								{
									NIM_BOOL T44_;
									T44_ = (NIM_BOOL)0;
									T44_ = S_ISDIR(s.st_mode);
									if (!T44_) goto LA45_;
									k = ((tyEnum_PathComponent__Rn0bieszZmgAu0Fd4CF7Yw) 2);
								}
								goto LA38_;
								LA45_: ;
								{
									NIM_BOOL T48_;
									T48_ = (NIM_BOOL)0;
									T48_ = S_ISLNK(s.st_mode);
									if (!T48_) goto LA49_;
									k = getSymlinkFileKind__pureZos_1244(path_2);
								}
								goto LA38_;
								LA49_: ;
								LA38_: ;
							}
							break;
							default:
							{
							}
							break;
							}
							kind = k;
							path = y;
							{
								NI T56_;
								NimStringDesc* T57_;
								if (!((filter &((NU8)1<<((NU)(kind)&7U)))!=0)) goto LA54_;
								result = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(result), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_));
								T56_ = result->Sup.len++;
								T57_ = NIM_NIL;
								T57_ = result->data[T56_]; result->data[T56_] = copyStringRC1(path);
								if (T57_) nimGCunrefNoCycle(T57_);
							}
							LA54_: ;
						}
						LA23_: ;
					} LA14: ;
				}
			} LA12: ;
			popSafePoint();
			}
			else {
				popSafePoint();
			}
			{
				int T60_;
				T60_ = (int)0;
				T60_ = closedir(d);
				(void)(T60_);
				if (TM__qdmBYobaV9btoxwHZNavLQA_9.status != 0) nimLeaveFinally();
			}
			if (TM__qdmBYobaV9btoxwHZNavLQA_9.status != 0) reraiseException();
		}
		LA2_: ;
	}
	setResult__vm_258(a, result);
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = NIM_NIL;
	result = currException__system_2566;
	return result;
}
static N_INLINE(NimStringDesc*, getCurrentExceptionMsg__system_6984)(void) {
	NimStringDesc* result;
{	result = NIM_NIL;
	{
		if (!(currException__system_2566 == ((Exception*) NIM_NIL))) goto LA3_;
		result = ((NimStringDesc*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		result = copyString((*currException__system_2566).message);
	}
	LA1_: ;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__system_2566), (*currException__system_2566).up);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_59)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_8;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_8);
	TM__qdmBYobaV9btoxwHZNavLQA_8.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_8.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_8.status == 0) {
	listDirs__scriptconfig_20(a, 3);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_8.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_8.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_61)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_13;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_13);
	TM__qdmBYobaV9btoxwHZNavLQA_13.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_13.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_13.status == 0) {
	listDirs__scriptconfig_20(a, 4);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_13.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_13.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_63)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_15;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_15);
	TM__qdmBYobaV9btoxwHZNavLQA_15.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_15.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_15.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 8));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		NIM_BOOL T9_;
		T8_ = NIM_NIL;
		T8_ = getString__vm_368(a, ((NI) 0));
		T9_ = (NIM_BOOL)0;
		T9_ = getBool__vm_314(a, ((NI) 1));
		nosremoveDir(T8_, T9_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_15.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_15.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_69)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_17;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_17);
	TM__qdmBYobaV9btoxwHZNavLQA_17.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_17.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_17.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 8));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		T8_ = NIM_NIL;
		T8_ = getString__vm_368(a, ((NI) 0));
		nosremoveFile(T8_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_17.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_17.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_75)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_19;
	NimStringDesc* T1_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_19);
	TM__qdmBYobaV9btoxwHZNavLQA_19.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_19.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_19.status == 0) {
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	noscreateDir(T1_);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_19.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_19.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_77)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	setResult__vm_249(a, (*colonenvP_).errorMsg1);
}
static N_INLINE(void, setCurrentDir__pureZos_732)(NimStringDesc* newDir) {
	{
		int T3_;
		NI32 T6_;
		T3_ = (int)0;
		T3_ = chdir(nimToCStringConv(newDir));
		if (!!((T3_ == ((NI32) 0)))) goto LA4_;
		T6_ = (NI32)0;
		T6_ = osLastError__pureZos_408();
		raiseOSError__pureZos_405(T6_, newDir);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_79)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_22;
	NimStringDesc* T1_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_22);
	TM__qdmBYobaV9btoxwHZNavLQA_22.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_22.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_22.status == 0) {
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	setCurrentDir__pureZos_732(T1_);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_22.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_22.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_81)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_24;
	NimStringDesc* T1_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_24);
	TM__qdmBYobaV9btoxwHZNavLQA_24.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_24.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_24.status == 0) {
	T1_ = NIM_NIL;
	T1_ = nosgetCurrentDir();
	setResult__vm_249(a, T1_);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_24.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_24.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_83)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_26;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_26);
	TM__qdmBYobaV9btoxwHZNavLQA_26.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_26.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_26.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 8));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		T8_ = NIM_NIL;
		T8_ = getString__vm_368(a, ((NI) 0));
		T9_ = NIM_NIL;
		T9_ = getString__vm_368(a, ((NI) 1));
		nosmoveFile(T8_, T9_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_26.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_26.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_89)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_28;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_28);
	TM__qdmBYobaV9btoxwHZNavLQA_28.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_28.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_28.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 8));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		T8_ = NIM_NIL;
		T8_ = getString__vm_368(a, ((NI) 0));
		T9_ = NIM_NIL;
		T9_ = getString__vm_368(a, ((NI) 1));
		moveDir__pureZos_1461(T8_, T9_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_28.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_28.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_95)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_30;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_30);
	TM__qdmBYobaV9btoxwHZNavLQA_30.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_30.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_30.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 8));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		T8_ = NIM_NIL;
		T8_ = getString__vm_368(a, ((NI) 0));
		T9_ = NIM_NIL;
		T9_ = getString__vm_368(a, ((NI) 1));
		noscopyFile(T8_, T9_, 2);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_30.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_30.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_101)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_32;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_32);
	TM__qdmBYobaV9btoxwHZNavLQA_32.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_32.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_32.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 8));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		T8_ = NIM_NIL;
		T8_ = getString__vm_368(a, ((NI) 0));
		T9_ = NIM_NIL;
		T9_ = getString__vm_368(a, ((NI) 1));
		noscopyDir(T8_, T9_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_32.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_32.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_107)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_34;
	NimStringDesc* T1_;
	tyObject_Time__4nyPibhNA9bJ9a0FBX1dYOaA T2_;
	NI64 T3_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_34);
	TM__qdmBYobaV9btoxwHZNavLQA_34.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_34.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_34.status == 0) {
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = nosgetLastModificationTime(T1_);
	T3_ = (NI64)0;
	T3_ = toUnix__pureZtimes_917(T2_);
	setResult__vm_236(a, T3_);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_34.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_34.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_109)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_36;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_36);
	TM__qdmBYobaV9btoxwHZNavLQA_36.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_36.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_36.status == 0) {
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = NIM_NIL;
	T2_ = findExe__pureZos_654(T1_, NIM_TRUE, ExeExts__pureZos_653, 1);
	setResult__vm_249(a, T2_);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_36.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_36.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_111)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_38;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_38);
	TM__qdmBYobaV9btoxwHZNavLQA_38.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_38.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_38.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 8));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		NI T9_;
		T8_ = NIM_NIL;
		T8_ = getString__vm_368(a, ((NI) 0));
		T9_ = (NI)0;
		T9_ = nospexecCmd(T8_);
		setResult__vm_236(a, ((NI64) (T9_)));
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_38.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_38.status != 0) reraiseException();
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_117)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = NIM_NIL;
	T2_ = getString__vm_368(a, ((NI) 1));
	T3_ = NIM_NIL;
	T3_ = getEnv__pureZos_418(T1_, T2_);
	setResult__vm_249(a, T3_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_119)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a) {
	NimStringDesc* T1_;
	NIM_BOOL T2_;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = (NIM_BOOL)0;
	T2_ = existsEnv__pureZos_423(T1_);
	setResult__vm_242(a, T2_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_121)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = NIM_NIL;
	T2_ = getString__vm_368(a, ((NI) 1));
	putEnv__pureZos_426(T1_, T2_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_123)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	delEnv__pureZos_465(T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_125)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a) {
	NimStringDesc* T1_;
	NIM_BOOL T2_;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = (NIM_BOOL)0;
	T2_ = nosdirExists(T1_);
	setResult__vm_242(a, T2_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_127)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a) {
	NimStringDesc* T1_;
	NIM_BOOL T2_;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = (NIM_BOOL)0;
	T2_ = nosfileExists(T1_);
	setResult__vm_242(a, T2_);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_129)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	setResult__vm_249(a, (*(*colonenvP_).conf3).projectName);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_131)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	setResult__vm_249(a, (*(*colonenvP_).conf3).projectPath);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_133)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	setResult__vm_249(a, (*(*colonenvP_).conf3).projectFull);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_135)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	setResult__vm_249(a, (*colonenvP_).vthisDir4);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_137)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = NIM_NIL;
	T2_ = getString__vm_368(a, ((NI) 1));
	setConfigVar__options_4059((*colonenvP_).conf3, T1_, T2_);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_139)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = NIM_NIL;
	T2_ = getConfigVar__options_4054((*colonenvP_).conf3, T1_, ((NimStringDesc*) NIM_NIL));
	setResult__vm_249(a, T2_);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_141)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	NimStringDesc* T1_;
	NIM_BOOL T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = (NIM_BOOL)0;
	T2_ = existsConfigVar__options_4050((*colonenvP_).conf3, T1_);
	setResult__vm_242(a, T2_);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_143)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	NimStringDesc* T1_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	T1_ = NIM_NIL;
	T1_ = getNimcacheDir__options_4185((*colonenvP_).conf3);
	setResult__vm_249(a, T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_145)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a) {
	NI64 T1_;
	NimStringDesc* T2_;
	T1_ = (NI64)0;
	T1_ = getInt__vm_279(a, ((NI) 0));
	T2_ = NIM_NIL;
	T2_ = paramStr__pureZos_1546(((NI) (T1_)));
	setResult__vm_249(a, T2_);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_147)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a) {
	NI T1_;
	T1_ = (NI)0;
	T1_ = paramCount__pureZos_1552();
	setResult__vm_236(a, ((NI64) (T1_)));
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_149)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	NI T3_;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = NIM_NIL;
	T2_ = getString__vm_368(a, ((NI) 1));
	T3_ = (NI)0;
	T3_ = nsuCmpIgnoreStyle(T1_, T2_);
	setResult__vm_236(a, ((NI64) (T3_)));
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_151)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	NI T3_;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = NIM_NIL;
	T2_ = getString__vm_368(a, ((NI) 1));
	T3_ = (NI)0;
	T3_ = nsuCmpIgnoreCase(T1_, T2_);
	setResult__vm_236(a, ((NI64) (T3_)));
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_153)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	NimStringDesc* T1_;
	NimStringDesc* arg;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	setCommandEarly__commands_832((*colonenvP_).conf3, T1_);
	arg = getString__vm_368(a, ((NI) 1));
	(*(*colonenvP_).conf3).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2)) & 63);
	{
		if (!(((NI) 0) < (arg ? arg->Sup.len : 0))) goto LA4_;
		setFromProjectName__options_4123((*colonenvP_).conf3, arg);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_160)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	setResult__vm_249(a, (*(*colonenvP_).conf3).command);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_162)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = NIM_NIL;
	T2_ = getString__vm_368(a, ((NI) 1));
	processSwitch__commands_880(T1_, T2_, ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 2), (*(*colonenvP_).module5).info, (*colonenvP_).conf3);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_164)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = NIM_NIL;
	T2_ = getString__vm_368(a, ((NI) 1));
	processSpecificNote__commands_274(T1_, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 124), ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 2), (*(*colonenvP_).module5).info, T2_, (*colonenvP_).conf3);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_166)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	T2_ = NIM_NIL;
	T2_ = getString__vm_368(a, ((NI) 1));
	processSpecificNote__commands_274(T1_, ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 123), ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 2), (*(*colonenvP_).module5).info, T2_, (*colonenvP_).conf3);
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_168)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	NimStringDesc* key;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	NimStringDesc* val;
	NimStringDesc* T4_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	T1_ = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = getString__vm_368(a, ((NI) 0));
	T3_ = NIM_NIL;
	T3_ = getString__vm_368(a, ((NI) 1));
	T1_ = rawNewString((T2_ ? T2_->Sup.len : 0) + (T3_ ? T3_->Sup.len : 0) + 1);
appendString(T1_, T2_);
appendString(T1_, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_73));
appendString(T1_, T3_);
	key = T1_;
	T4_ = NIM_NIL;
	T4_ = getString__vm_368(a, ((NI) 2));
	val = nosaddFileExt(T4_, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_74));
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = contains__pureZstrutils_1631(val, TM__qdmBYobaV9btoxwHZNavLQA_75);
		if (!T7_) goto LA8_;
		val = pathSubs__options_4207((*colonenvP_).conf3, val, (*colonenvP_).vthisDir4);
	}
	goto LA5_;
	LA8_: ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = nosisAbsolute(val);
		if (!!(T11_)) goto LA12_;
		val = slash___pureZos_121((*colonenvP_).vthisDir4, val);
	}
	goto LA5_;
	LA12_: ;
	LA5_: ;
	nstPut((*(*colonenvP_).conf3).moduleOverrides, key, val);
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_172)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = nosgetAppFilename();
	setResult__vm_249(a, T1_);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_174)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	NimStringDesc* T1_;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	T1_ = NIM_NIL;
	T1_ = getString__vm_368(a, ((NI) 0));
	cppDefine__options_2530((*colonenvP_).conf3, T1_);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_176)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_80;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_80);
	TM__qdmBYobaV9btoxwHZNavLQA_80.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_80.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_80.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 8));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		setResult__vm_249(a, ((NimStringDesc*) NIM_NIL));
		T8_ = NIM_NIL;
		T8_ = readLine__systemZio_273(__stdinp);
		setResult__vm_249(a, T8_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIeoferror__kIdEdoaj8I8RXN2AU5W3mg_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_80.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_80.status != 0) reraiseException();
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_182)(tyObject_VmArgs__pcDb3SOJLe7g9bzr1B27LMA* a, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenvP_;
	TSafePoint TM__qdmBYobaV9btoxwHZNavLQA_82;
	colonenvP_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) ClE_0;
	asgnRef((void**) (&(*colonenvP_).errorMsg1), ((NimStringDesc*) NIM_NIL));
	pushSafePoint(&TM__qdmBYobaV9btoxwHZNavLQA_82);
	TM__qdmBYobaV9btoxwHZNavLQA_82.status = _setjmp(TM__qdmBYobaV9btoxwHZNavLQA_82.context);
	if (TM__qdmBYobaV9btoxwHZNavLQA_82.status == 0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_FALSE;
		if (T3_) goto LA4_;
		T3_ = ((*(*(*colonenvP_).graph2).config).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 8));
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		setResult__vm_249(a, ((NimStringDesc*) NIM_NIL));
		T8_ = NIM_NIL;
		T8_ = readAll__systemZio_352(__stdinp);
		setResult__vm_249(a, T8_);
	}
	LA1_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIeoferror__kIdEdoaj8I8RXN2AU5W3mg_))) {
			TM__qdmBYobaV9btoxwHZNavLQA_82.status = 0;
			asgnRef((void**) (&(*colonenvP_).errorMsg1), getCurrentExceptionMsg__system_6984());
			popCurrentException();
		}
	}
	if (TM__qdmBYobaV9btoxwHZNavLQA_82.status != 0) reraiseException();
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ*, setupVM__scriptconfig_39)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* module, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NimStringDesc* scriptName, tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* result;
	tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA* colonenv_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T1_;
	NimStringDesc* T2_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T3_;
	NI T4_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T5_;
	NI T6_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T7_;
	NI T8_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T9_;
	NI T10_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T11_;
	NI T12_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T13_;
	NI T14_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T15_;
	NI T16_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T17_;
	NI T18_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T19_;
	NI T20_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T21_;
	NI T22_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T23_;
	NI T24_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T25_;
	NI T26_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T27_;
	NI T28_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T29_;
	NI T30_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T31_;
	NI T32_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T33_;
	NI T34_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T35_;
	NI T36_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T37_;
	NI T38_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T39_;
	NI T40_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T41_;
	NI T42_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T43_;
	NI T44_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T45_;
	NI T46_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T47_;
	NI T48_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T49_;
	NI T50_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T51_;
	NI T52_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T53_;
	NI T54_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T55_;
	NI T56_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T57_;
	NI T58_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T59_;
	NI T60_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T61_;
	NI T62_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T63_;
	NI T64_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T65_;
	NI T66_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T67_;
	NI T68_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T69_;
	NI T70_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T71_;
	NI T72_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T73_;
	NI T74_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T75_;
	NI T76_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T77_;
	NI T78_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T79_;
	NI T80_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T81_;
	NI T82_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T83_;
	NI T84_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T85_;
	NI T86_;
	tyProc__vkuGXw0bPP9b9cpazTHQY9bqg T87_;
	NI T88_;
	result = NIM_NIL;
	colonenv_ = NIM_NIL;
	colonenv_ = (tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*) newObj((&NTIrefobject__X7o3ECzpPdUpRzG3oZpgiQ_), sizeof(tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA));
	(*colonenv_).Sup.m_type = (&NTIobject__heNwa9aLhgGVTGhbmP9aqemA_);
	asgnRef((void**) (&(*colonenv_).module5), module);
	asgnRef((void**) (&(*colonenv_).graph2), graph);
	result = newCtx__vmdef_367((*colonenv_).module5, cache, (*colonenv_).graph2, idgen);
	(*result).mode = ((tyEnum_TEvalMode__iWSxkwmhTDY7fh9aYmp69akQ) 0);
	registerAdditionalOps__vm_13319(result);
	asgnRef((void**) (&(*colonenv_).conf3), (*(*colonenv_).graph2).config);
	asgnRef((void**) (&(*colonenv_).errorMsg1), NIM_NIL);
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	nossplitFile(scriptName, (&T1_));
	T2_ = NIM_NIL;
	T2_ = (*colonenv_).vthisDir4; (*colonenv_).vthisDir4 = copyStringRC1(T1_.Field0);
	if (T2_) nimGCunrefNoCycle(T2_);
	nimZeroMem((void*)(&T3_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T3_.ClP_0 = colonanonymous___scriptconfig_59; T3_.ClE_0 = colonenv_;
	T4_ = (NI)0;
	T4_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_7), T3_);
	nimZeroMem((void*)(&T5_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T5_.ClP_0 = colonanonymous___scriptconfig_61; T5_.ClE_0 = colonenv_;
	T6_ = (NI)0;
	T6_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_12), T5_);
	nimZeroMem((void*)(&T7_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T7_.ClP_0 = colonanonymous___scriptconfig_63; T7_.ClE_0 = colonenv_;
	T8_ = (NI)0;
	T8_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_14), T7_);
	nimZeroMem((void*)(&T9_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T9_.ClP_0 = colonanonymous___scriptconfig_69; T9_.ClE_0 = colonenv_;
	T10_ = (NI)0;
	T10_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_16), T9_);
	nimZeroMem((void*)(&T11_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T11_.ClP_0 = colonanonymous___scriptconfig_75; T11_.ClE_0 = colonenv_;
	T12_ = (NI)0;
	T12_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_18), T11_);
	nimZeroMem((void*)(&T13_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T13_.ClP_0 = colonanonymous___scriptconfig_77; T13_.ClE_0 = colonenv_;
	T14_ = (NI)0;
	T14_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_20), T13_);
	nimZeroMem((void*)(&T15_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T15_.ClP_0 = colonanonymous___scriptconfig_79; T15_.ClE_0 = colonenv_;
	T16_ = (NI)0;
	T16_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_21), T15_);
	nimZeroMem((void*)(&T17_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T17_.ClP_0 = colonanonymous___scriptconfig_81; T17_.ClE_0 = colonenv_;
	T18_ = (NI)0;
	T18_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_23), T17_);
	nimZeroMem((void*)(&T19_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T19_.ClP_0 = colonanonymous___scriptconfig_83; T19_.ClE_0 = colonenv_;
	T20_ = (NI)0;
	T20_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_25), T19_);
	nimZeroMem((void*)(&T21_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T21_.ClP_0 = colonanonymous___scriptconfig_89; T21_.ClE_0 = colonenv_;
	T22_ = (NI)0;
	T22_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_27), T21_);
	nimZeroMem((void*)(&T23_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T23_.ClP_0 = colonanonymous___scriptconfig_95; T23_.ClE_0 = colonenv_;
	T24_ = (NI)0;
	T24_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_29), T23_);
	nimZeroMem((void*)(&T25_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T25_.ClP_0 = colonanonymous___scriptconfig_101; T25_.ClE_0 = colonenv_;
	T26_ = (NI)0;
	T26_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_31), T25_);
	nimZeroMem((void*)(&T27_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T27_.ClP_0 = colonanonymous___scriptconfig_107; T27_.ClE_0 = colonenv_;
	T28_ = (NI)0;
	T28_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_33), T27_);
	nimZeroMem((void*)(&T29_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T29_.ClP_0 = colonanonymous___scriptconfig_109; T29_.ClE_0 = colonenv_;
	T30_ = (NI)0;
	T30_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_35), T29_);
	nimZeroMem((void*)(&T31_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T31_.ClP_0 = colonanonymous___scriptconfig_111; T31_.ClE_0 = colonenv_;
	T32_ = (NI)0;
	T32_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_37), T31_);
	nimZeroMem((void*)(&T33_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T33_.ClP_0 = ((TM__qdmBYobaV9btoxwHZNavLQA_40) (colonanonymous___scriptconfig_117)); T33_.ClE_0 = NIM_NIL;
	T34_ = (NI)0;
	T34_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_39), T33_);
	nimZeroMem((void*)(&T35_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T35_.ClP_0 = ((TM__qdmBYobaV9btoxwHZNavLQA_42) (colonanonymous___scriptconfig_119)); T35_.ClE_0 = NIM_NIL;
	T36_ = (NI)0;
	T36_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_41), T35_);
	nimZeroMem((void*)(&T37_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T37_.ClP_0 = ((TM__qdmBYobaV9btoxwHZNavLQA_44) (colonanonymous___scriptconfig_121)); T37_.ClE_0 = NIM_NIL;
	T38_ = (NI)0;
	T38_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_43), T37_);
	nimZeroMem((void*)(&T39_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T39_.ClP_0 = ((TM__qdmBYobaV9btoxwHZNavLQA_46) (colonanonymous___scriptconfig_123)); T39_.ClE_0 = NIM_NIL;
	T40_ = (NI)0;
	T40_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_45), T39_);
	nimZeroMem((void*)(&T41_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T41_.ClP_0 = ((TM__qdmBYobaV9btoxwHZNavLQA_48) (colonanonymous___scriptconfig_125)); T41_.ClE_0 = NIM_NIL;
	T42_ = (NI)0;
	T42_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_47), T41_);
	nimZeroMem((void*)(&T43_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T43_.ClP_0 = ((TM__qdmBYobaV9btoxwHZNavLQA_50) (colonanonymous___scriptconfig_127)); T43_.ClE_0 = NIM_NIL;
	T44_ = (NI)0;
	T44_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_49), T43_);
	nimZeroMem((void*)(&T45_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T45_.ClP_0 = colonanonymous___scriptconfig_129; T45_.ClE_0 = colonenv_;
	T46_ = (NI)0;
	T46_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_51), T45_);
	nimZeroMem((void*)(&T47_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T47_.ClP_0 = colonanonymous___scriptconfig_131; T47_.ClE_0 = colonenv_;
	T48_ = (NI)0;
	T48_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_52), T47_);
	nimZeroMem((void*)(&T49_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T49_.ClP_0 = colonanonymous___scriptconfig_133; T49_.ClE_0 = colonenv_;
	T50_ = (NI)0;
	T50_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_53), T49_);
	nimZeroMem((void*)(&T51_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T51_.ClP_0 = colonanonymous___scriptconfig_135; T51_.ClE_0 = colonenv_;
	T52_ = (NI)0;
	T52_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_54), T51_);
	nimZeroMem((void*)(&T53_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T53_.ClP_0 = colonanonymous___scriptconfig_137; T53_.ClE_0 = colonenv_;
	T54_ = (NI)0;
	T54_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_55), T53_);
	nimZeroMem((void*)(&T55_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T55_.ClP_0 = colonanonymous___scriptconfig_139; T55_.ClE_0 = colonenv_;
	T56_ = (NI)0;
	T56_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_56), T55_);
	nimZeroMem((void*)(&T57_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T57_.ClP_0 = colonanonymous___scriptconfig_141; T57_.ClE_0 = colonenv_;
	T58_ = (NI)0;
	T58_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_57), T57_);
	nimZeroMem((void*)(&T59_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T59_.ClP_0 = colonanonymous___scriptconfig_143; T59_.ClE_0 = colonenv_;
	T60_ = (NI)0;
	T60_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_58), T59_);
	nimZeroMem((void*)(&T61_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T61_.ClP_0 = ((TM__qdmBYobaV9btoxwHZNavLQA_60) (colonanonymous___scriptconfig_145)); T61_.ClE_0 = NIM_NIL;
	T62_ = (NI)0;
	T62_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_59), T61_);
	nimZeroMem((void*)(&T63_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T63_.ClP_0 = ((TM__qdmBYobaV9btoxwHZNavLQA_62) (colonanonymous___scriptconfig_147)); T63_.ClE_0 = NIM_NIL;
	T64_ = (NI)0;
	T64_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_61), T63_);
	nimZeroMem((void*)(&T65_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T65_.ClP_0 = ((TM__qdmBYobaV9btoxwHZNavLQA_64) (colonanonymous___scriptconfig_149)); T65_.ClE_0 = NIM_NIL;
	T66_ = (NI)0;
	T66_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_63), T65_);
	nimZeroMem((void*)(&T67_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T67_.ClP_0 = ((TM__qdmBYobaV9btoxwHZNavLQA_66) (colonanonymous___scriptconfig_151)); T67_.ClE_0 = NIM_NIL;
	T68_ = (NI)0;
	T68_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_65), T67_);
	nimZeroMem((void*)(&T69_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T69_.ClP_0 = colonanonymous___scriptconfig_153; T69_.ClE_0 = colonenv_;
	T70_ = (NI)0;
	T70_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_67), T69_);
	nimZeroMem((void*)(&T71_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T71_.ClP_0 = colonanonymous___scriptconfig_160; T71_.ClE_0 = colonenv_;
	T72_ = (NI)0;
	T72_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_68), T71_);
	nimZeroMem((void*)(&T73_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T73_.ClP_0 = colonanonymous___scriptconfig_162; T73_.ClE_0 = colonenv_;
	T74_ = (NI)0;
	T74_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_69), T73_);
	nimZeroMem((void*)(&T75_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T75_.ClP_0 = colonanonymous___scriptconfig_164; T75_.ClE_0 = colonenv_;
	T76_ = (NI)0;
	T76_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_70), T75_);
	nimZeroMem((void*)(&T77_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T77_.ClP_0 = colonanonymous___scriptconfig_166; T77_.ClE_0 = colonenv_;
	T78_ = (NI)0;
	T78_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_71), T77_);
	nimZeroMem((void*)(&T79_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T79_.ClP_0 = colonanonymous___scriptconfig_168; T79_.ClE_0 = colonenv_;
	T80_ = (NI)0;
	T80_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_72), T79_);
	nimZeroMem((void*)(&T81_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T81_.ClP_0 = ((TM__qdmBYobaV9btoxwHZNavLQA_77) (colonanonymous___scriptconfig_172)); T81_.ClE_0 = NIM_NIL;
	T82_ = (NI)0;
	T82_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_76), T81_);
	nimZeroMem((void*)(&T83_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T83_.ClP_0 = colonanonymous___scriptconfig_174; T83_.ClE_0 = colonenv_;
	T84_ = (NI)0;
	T84_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_78), T83_);
	nimZeroMem((void*)(&T85_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T85_.ClP_0 = colonanonymous___scriptconfig_176; T85_.ClE_0 = colonenv_;
	T86_ = (NI)0;
	T86_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_79), T85_);
	nimZeroMem((void*)(&T87_), sizeof(tyProc__vkuGXw0bPP9b9cpazTHQY9bqg));
	T87_.ClP_0 = colonanonymous___scriptconfig_182; T87_.ClE_0 = colonenv_;
	T88_ = (NI)0;
	T88_ = registerCallback__vmdef_518(result, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_81), T87_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, runNimScript__scriptconfig_188)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NimStringDesc* scriptName, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, NIM_BOOL freshDefines, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* stream) {
	tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg oldSymbolFiles;
	tyObject_ModuleGraphcolonObjectType___nOSrcYqJTxXt2ptNc0gnWg* graph;
	tyTuple__nF9cH4hinXgGEUwO4G2bshw T5_;
	tyTuple__nF9cH4hinXgGEUwO4G2bshw T6_;
	NI T7_;
	NimStringDesc* T8_;
	tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg oldGlobalOptions;
	tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w oldSelectedGC;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* m;
	tyObject_TCtx__CRPlhL1hATwZc5hefTGOQQ* vm;
	NIM_BOOL T9_;
	oldSymbolFiles = (*conf).symbolFiles;
	(*conf).symbolFiles = ((tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg) 0);
	graph = newModuleGraph__modulegraphs_9478(cache, conf);
	connectCallbacks__modules_1183(graph);
	{
		if (!freshDefines) goto LA3_;
		initDefines__condsyms_18((*conf).symbols);
	}
	LA3_: ;
	defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_2), ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_3));
	defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_4), ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_3));
	T5_.Field0 = myOpen__sem_22328;
	T5_.Field1 = myProcess__sem_22542;
	T5_.Field2 = myClose__sem_22570;
	T5_.Field3 = NIM_TRUE;
	registerPass__passes_63(graph, (&T5_));
	T6_.Field0 = myOpen__vm_14031;
	T6_.Field1 = myProcess__vm_14036;
	T6_.Field2 = myClose__vm_14041;
	T6_.Field3 = NIM_FALSE;
	registerPass__passes_63(graph, (&T6_));
	asgnRef((void**) (&(*conf).searchPaths), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).searchPaths), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
	T7_ = (*conf).searchPaths->Sup.len++;
	T8_ = NIM_NIL;
	T8_ = (*conf).searchPaths->data[T7_]; (*conf).searchPaths->data[T7_] = copyStringRC1((*conf).libpath);
	if (T8_) nimGCunrefNoCycle(T8_);
	oldGlobalOptions = (*conf).globalOptions;
	oldSelectedGC = (*conf).selectedGC;
	undefSymbol__condsyms_8((*conf).symbols, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_5));
	(*conf).globalOptions = ((*conf).globalOptions & ~ IL64(7696581394432));
	(*conf).selectedGC = ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 0);
	m = makeModule__modules_1225(graph, scriptName);
	(*m).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 14)) & 63);
	vm = setupVM__scriptconfig_39(m, cache, scriptName, graph, idgen);
	asgnRef((void**) (&(*graph).vm), &vm->Sup.Sup);
	compileSystemModule__modules_1203(graph);
	T9_ = (NIM_BOOL)0;
	T9_ = processModule__passes_213(graph, m, (*vm).Sup.idgen, stream);
	(void)(T9_);
	{
		if (!((*conf).selectedGC == ((tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w) 0))) goto LA12_;
		(*conf).selectedGC = oldSelectedGC;
	}
	LA12_: ;
	{
		if (!((oldGlobalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 42))&63U)))!=0)) goto LA16_;
		(*conf).globalOptions = ((*conf).globalOptions | IL64(7696581394432));
		defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_5), ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_3));
	}
	LA16_: ;
	{
		if (!((48 &((NU16)1<<((NU)((*conf).selectedGC)&15U)))!=0)) goto LA20_;
		(*conf).globalOptions = ((*conf).globalOptions | IL64(3298534883328));
		defineSymbol__condsyms_4((*conf).symbols, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_5), ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_3));
	}
	LA20_: ;
	resetSystemArtifacts__modules_17(graph);
	undefSymbol__condsyms_8((*conf).symbols, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_2));
	undefSymbol__condsyms_8((*conf).symbols, ((NimStringDesc*) &TM__qdmBYobaV9btoxwHZNavLQA_4));
	(*conf).symbolFiles = oldSymbolFiles;
}
N_LIB_PRIVATE N_NIMCALL(void, atmscriptconfigdotnim_DatInit000)(void) {
static TNimNode* TM__qdmBYobaV9btoxwHZNavLQA_6_6[6];
static TNimNode TM__qdmBYobaV9btoxwHZNavLQA_0[7];
NTIobject__heNwa9aLhgGVTGhbmP9aqemA_.size = sizeof(tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA);
NTIobject__heNwa9aLhgGVTGhbmP9aqemA_.align = NIM_ALIGNOF(tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA);
NTIobject__heNwa9aLhgGVTGhbmP9aqemA_.kind = 17;
NTIobject__heNwa9aLhgGVTGhbmP9aqemA_.base = (&NTIrootobj__ytyiCJqK439aF9cIibuRVpAg_);
TM__qdmBYobaV9btoxwHZNavLQA_6_6[0] = &TM__qdmBYobaV9btoxwHZNavLQA_0[1];
TM__qdmBYobaV9btoxwHZNavLQA_0[1].kind = 1;
TM__qdmBYobaV9btoxwHZNavLQA_0[1].offset = offsetof(tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA, colonstate_);
TM__qdmBYobaV9btoxwHZNavLQA_0[1].typ = (&NTIint__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__qdmBYobaV9btoxwHZNavLQA_0[1].name = ":state";
TM__qdmBYobaV9btoxwHZNavLQA_6_6[1] = &TM__qdmBYobaV9btoxwHZNavLQA_0[2];
TM__qdmBYobaV9btoxwHZNavLQA_0[2].kind = 1;
TM__qdmBYobaV9btoxwHZNavLQA_0[2].offset = offsetof(tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA, errorMsg1);
TM__qdmBYobaV9btoxwHZNavLQA_0[2].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__qdmBYobaV9btoxwHZNavLQA_0[2].name = "errorMsg1";
TM__qdmBYobaV9btoxwHZNavLQA_6_6[2] = &TM__qdmBYobaV9btoxwHZNavLQA_0[3];
TM__qdmBYobaV9btoxwHZNavLQA_0[3].kind = 1;
TM__qdmBYobaV9btoxwHZNavLQA_0[3].offset = offsetof(tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA, graph2);
TM__qdmBYobaV9btoxwHZNavLQA_0[3].typ = (&NTImodulegraph__AcDjMYSN0KX1UsX3HvPu2w_);
TM__qdmBYobaV9btoxwHZNavLQA_0[3].name = "graph2";
TM__qdmBYobaV9btoxwHZNavLQA_6_6[3] = &TM__qdmBYobaV9btoxwHZNavLQA_0[4];
TM__qdmBYobaV9btoxwHZNavLQA_0[4].kind = 1;
TM__qdmBYobaV9btoxwHZNavLQA_0[4].offset = offsetof(tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA, conf3);
TM__qdmBYobaV9btoxwHZNavLQA_0[4].typ = (&NTIconfigref__9af1bTLFo0lbM2Q5seW0UFA_);
TM__qdmBYobaV9btoxwHZNavLQA_0[4].name = "conf3";
TM__qdmBYobaV9btoxwHZNavLQA_6_6[4] = &TM__qdmBYobaV9btoxwHZNavLQA_0[5];
TM__qdmBYobaV9btoxwHZNavLQA_0[5].kind = 1;
TM__qdmBYobaV9btoxwHZNavLQA_0[5].offset = offsetof(tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA, vthisDir4);
TM__qdmBYobaV9btoxwHZNavLQA_0[5].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__qdmBYobaV9btoxwHZNavLQA_0[5].name = "vthisDir4";
TM__qdmBYobaV9btoxwHZNavLQA_6_6[5] = &TM__qdmBYobaV9btoxwHZNavLQA_0[6];
TM__qdmBYobaV9btoxwHZNavLQA_0[6].kind = 1;
TM__qdmBYobaV9btoxwHZNavLQA_0[6].offset = offsetof(tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA, module5);
TM__qdmBYobaV9btoxwHZNavLQA_0[6].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__qdmBYobaV9btoxwHZNavLQA_0[6].name = "module5";
TM__qdmBYobaV9btoxwHZNavLQA_0[0].len = 6; TM__qdmBYobaV9btoxwHZNavLQA_0[0].kind = 2; TM__qdmBYobaV9btoxwHZNavLQA_0[0].sons = &TM__qdmBYobaV9btoxwHZNavLQA_6_6[0];
NTIobject__heNwa9aLhgGVTGhbmP9aqemA_.node = &TM__qdmBYobaV9btoxwHZNavLQA_0[0];
NTIrefobject__X7o3ECzpPdUpRzG3oZpgiQ_.size = sizeof(tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*);
NTIrefobject__X7o3ECzpPdUpRzG3oZpgiQ_.align = NIM_ALIGNOF(tyObject_Env_scriptconfigdotnim_setupVM___heNwa9aLhgGVTGhbmP9aqemA*);
NTIrefobject__X7o3ECzpPdUpRzG3oZpgiQ_.kind = 22;
NTIrefobject__X7o3ECzpPdUpRzG3oZpgiQ_.base = (&NTIobject__heNwa9aLhgGVTGhbmP9aqemA_);
NTIrefobject__X7o3ECzpPdUpRzG3oZpgiQ_.marker = Marker_tyRef__X7o3ECzpPdUpRzG3oZpgiQ;
}

